sfr-slack-api: The Slack API Client.
The sfr-slack-api provides the client of Slack API.
Currently, only the parts that the author uses are implemented.
sfr-slack-api is the parts of slack-framework-rs.
See slack-framework-rs for details.
Structs
- Chat
Post Message - The request object for https://api.slack.com/methods/chat.postMessage.
- Chat
Post Message Builder - The builder for
ChatPostMessage. - Chat
Post Message Response - The type that represents a response of
chat.postMessage. - Client
- The client for Slack API without OAuth.
- Files
Complete Upload External - The request object for https://api.slack.com/methods/files.completeUploadExternal.
- Files
Complete Upload External Builder - The builder for
FilesCompleteUploadExternal. - Files
Complete Upload External Response - The type that represents a response of
files.completeUploadExternal. - Files
GetUpload UrlExternal - The request object for https://api.slack.com/methods/files.getUploadURLExternal.
- Files
GetUpload UrlExternal Builder - The builder for
FilesGetUploadUrlExternal. - Files
GetUpload UrlExternal Response - The type that represents a response of
files.getUploadURLExternal. - Files
Info - The request object for https://api.slack.com/methods/files.info.
- Files
Info Builder - The builder for
FilesInfo. - Files
Info Response - The type that represents a response of
files.info. - Files
Remote Add - The request object for https://api.slack.com/methods/files.remote.add.
- Files
Remote AddBuilder - The builder for
FilesRemoteAdd. - Files
Remote AddResponse - The type that represents a response of
files.remote.add. - Files
Upload - The request object for https://api.slack.com/methods/files.upload.
- Files
Upload Builder - The builder for
FilesUpload. - Files
Upload Response - The type that represents a response of
files.upload. - Oauth
Client - The client for Slack API about OAuth.
- Request
Builder - The builder for a request of Slack API.
Traits
- Request
- The type that represents a request for Slack API.